#[non_exhaustive]pub struct ParallelPlan {
pub workers: usize,
pub warmup_frames: usize,
pub redundant_frames: usize,
pub ranges: Vec<(usize, usize)>,
}Expand description
How a parallel encode will be divided up, from ParallelConfig::plan.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.workers: usizeThreads that will actually run. 1 means the encode is serial, whatever
was requested.
warmup_frames: usizeFrames of priming each worker after the first re-encodes and discards.
redundant_frames: usizeTotal frames that will be encoded and thrown away.
ranges: Vec<(usize, usize)>Half-open [start, end) frame range per worker, in output order.
Implementations